# Praktikum 13 aruanne
Antud praktikumis sain harjutada PowerShell`i skriptimist, mis ei olnud lihtne, kuid seal sai väga mugavalt andmeid
esitada tabelitena, mida PowerShell vaikimisi välja printis. Töö tegemisel kasutati korralikult ChatGPT abi.


[PowerShell'i fail](files/infofetch.ps1)

[PowerShell'i väljundi fail](files/infofetch-output.txt)

## Olulised käsud ja käsu osad
Ühed olulised käsud on:
1) `Select-Object` -- võimaldab valida objektil teatud omaduse ja vajadusel seda käitleda sobivale kujule.
2) `Get-WmiObject` -- võimaldab ligi pääseda WMI (Windows Management Instrumentation) objektidele, kus on palju infot
3) `Get-ItemProperty` -- võimaldab objekti omadusi kätte saada, antud skriptis kasutatakse seda Windows'i registri 
andmete kätte saamiseks
4) `Get-NetIPConfiguration`, `Get-NetAdapter` -- võimaldavad võrguliidese kohta infot saada.
5) `Format-Table` -- formaadib tabelit, kus saad valida, mis tulpe vaja on, ja laiendada tulba laiust.
6) `Sort-Object` -- sorteerib listi vastavalt omadusele ja ettesätestatud järjekorra järgi (suurenev, kahanev jne)

See pole täielik ning skriptis kasutatakse veel PowerShell'i käske, mida pole nimekirjas mainitud.

```powershell
$hostname = iex hostname
Write-Output ("Masina nimi: {0}" -f $hostname)

$ps_version = $PSVersionTable.PSVersion.ToString()
Write-Output ("PowerShell'i versioon: {0}" -f $ps_version)

$computer_info = Get-ComputerInfo
$windows_productname = $computer_info.OsName
$windows_version = (Get-ItemProperty -Path 'HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion').DisplayVersion
$windows_build = $computer_info.OsVersion.Split('.')[2]
Write-Output ("Windows'i versioon: {0} {1} (Build {2})" -f $windows_productname, $windows_version, $windows_build)

$netAdapter = Get-NetIPConfiguration | Where-Object { $_.IPv4DefaultGateway -ne $null }
$ipv4 = ($netAdapter | Select-Object @{Name='IPv4Address';Expression={$_.IPv4Address.IPAddress}}).IPv4Address
$netmask = ($netAdapter | Select-Object @{Name='SubnetMask';Expression={$_.IPv4Address.PrefixLength}}).SubnetMask
$netgateway = ($netAdapter | Select-Object @{Name='DefaultGateway';Expression={$_.IPv4DefaultGateway.NextHop}}).DefaultGateway
$adapterDetails = Get-NetAdapter | Where-Object { $_.Name -eq $netAdapter.InterfaceAlias }
$mac_address = $adapterDetails.MacAddress
$dhcp = (Get-NetIPConfiguration -Detailed  | Where-Object { $_.IPv4DefaultGateway -ne $null } | select @{N="DHCP";E={$_.NetIPv4Interface.DHCP}}).DHCP
Write-Output ("IP aadress: {0}" -f $ipv4) ("Võrgumask: {0}" -f $netmask) ("Gateway: {0}" -f $netgateway) ("DHCP: {0}" -f $dhcp) ("MAC aadress: {0}" -f $mac_address)

$memory_gb = [Math]::Round((Get-WmiObject Win32_ComputerSystem).TotalPhysicalMemory / [Math]::Pow(2, 30), 1)
$processor_name = $computer_info.CsProcessors.Name
Write-Output ("Protsessor: {0}" -f $processor_name) ("Mälu: {0} GB" -f $memory_gb)

Write-Output "GPU-d:"
(Get-WmiObject Win32_VideoController) | Select-Object Name, DriverVersion, @{Name="DriverDate";Expression={([Management.ManagementDateTimeConverter]::ToDateTime($_.DriverDate))}} | Format-Table -AutoSize


# ChatGPT written code
function Get-ReadableSize {
    param (
        [Parameter(Mandatory=$true)]
        [int64]$sizeInBytes
    )

    # Determine the appropriate unit (KB, MB, GB, TB) based on the size
    if ($sizeInBytes -ge 1TB) {
        # Convert to TB
        $size = [math]::round($sizeInBytes / 1TB, 2)
        $unit = "TB"
    } elseif ($sizeInBytes -ge 1GB) {
        # Convert to GB
        $size = [math]::round($sizeInBytes / 1GB, 2)
        $unit = "GB"
    } elseif ($sizeInBytes -ge 1MB) {
        # Convert to MB
        $size = [math]::round($sizeInBytes / 1MB, 2)
        $unit = "MB"
    } elseif ($sizeInBytes -ge 1KB) {
        # Convert to KB
        $size = [math]::round($sizeInBytes / 1KB, 2)
        $unit = "KB"
    } else {
        # If the size is smaller than 1KB, display in bytes
        $size = $sizeInBytes
        $unit = "Bytes"
    }

    # Return the formatted size with unit
    return "$size $unit"
}

Write-Output "Kettad:"
$partitions = Get-Partition
for ($i = 0; $i -lt $partitions.Length; $i++) {
    $partition = $partitions[$i]
    $kettat2ht = ""
    if ($partition.DriveLetter) {
        $space_free = Get-ReadableSize -sizeInBytes (Get-Volume -DriveLetter $partition.DriveLetter).SizeRemaining
        $kettat2ht = "kettatäht: {0}, vaba: {1}, " -f $partition.DriveLetter, $space_free
    }
    Write-Output ("{0}. partitsioon, {1}suurus: {2} ja tüüp: {3}" -f ($i + 1), $kettat2ht, (Get-ReadableSize -sizeInBytes $partition.Size), $partition.Type)
}

Write-Output ""

Write-Output "PCI seadmed:"
Get-WmiObject -Class Win32_PnpSignedDriver | Where-Object {$_.DeviceID -like "PCI*"} | Select-Object Description,Manufacturer,DriverVersion | Sort-Object Description | Format-Table -AutoSize

Write-Output "Arvutis olevad kasutajad:"
Get-CimInstance -ClassName Win32_UserAccount | Format-Table -Property Name, Description, LocalAccount, Disabled -AutoSize

Write-Output ("Käimasolevate protsesside arv: {0}" -f ((Get-Process).Count))

Write-Output ("10 viimasena käivitatud protsessi")
Get-WmiObject Win32_Process | Sort-Object CreationDate -Descending | Select-Object -First 10 Name, ProcessId, @{Name="CreationDate";Expression={([Management.ManagementDateTimeConverter]::ToDateTime($_.CreationDate))}} | Format-Table -AutoSize

Write-Output ("Täna on {0}" -f (Get-Date -Format "yyyy-MM-dd HH:mm:ss"))
```